@@ -2,7 +2,8 @@
 #'
 #' This function extracts relevant information from multiple simulations of the
 #' same trial specification in a tidy `data.frame` (1 simulation per row).
-#' See also the [summary()] function.
+#' See also the [check_performance()] and [summary()] functions, that uses the
+#' output from this function to further summarise simulation results..
 #'
 #' @param object `trial_results` object, output from the [run_trials()]
 #'   function.
@@ -64,6 +65,17 @@
 #'   selected arm to the comparator arm, as described for `te_comp` and below).
 #'   If `TRUE`, the raw estimates (`raw_ests`, see [setup_trial()] and
 #'   [run_trial()]) will be used instead of the posterior estimates.
+#' @param final_ests single logical. If `TRUE` (recommended) the final estimates
+#'   calculated using outcome data from all patients randomised when trials are
+#'   stopped is used; if `FALSE`, the estimates calculated for each arm when an
+#'   arm is stopped (or at the last adaptive analysis if not before) using data
+#'   from patients having reach followed up at this time point and not all
+#'   patients randomised. If `NULL` (the default), this argument will be set to
+#'   `FALSE` if outcome data are available immediate after randomisation for all
+#'   patients (for backwards compatibility, as final posterior estimates may
+#'   vary slightly in this situation, even if using the same data); otherwise it
+#'   will be said to `TRUE`. See [setup_trial()] for more details on how these
+#'   estimates are calculated.
 #'
 #' @return A `data.frame` containing the following columns:
 #'   \itemize{
@@ -110,17 +122,26 @@
 #'
 #' @export
 #'
+#' @seealso
+#' [check_performance()], [summary()], [plot_convergence()].
+#'
 
 extract_results <- function(object,
                             select_strategy = "control if available",
                             select_last_arm = FALSE,
                             select_preferences = NULL,
                             te_comp = NULL,
-                            raw_ests = FALSE) {
+                            raw_ests = FALSE,
+                            final_ests = NULL) {
 
   # Validate input (only checks class)
   if (!inherits(object, "trial_results")){
-    stop("object must be an output from the run_trials function.", call. = FALSE)
+    stop0("object must be an output from the run_trials function.")
+  }
+
+  # Set final_ests
+  if (is.null(final_ests)) {
+    final_ests <- !all(object$trial_spec$data_looks == object$trial_spec$randomised_at_looks)
   }
 
   # Extract values necessary for summarising results
@@ -131,34 +152,34 @@ extract_results <- function(object,
 
   # Validate selection strategy
   if (is.null(select_strategy) || length(select_strategy ) != 1){
-    stop("select_strategy  must be either 'control if available', 'none', ",
-         "control', 'final control', 'control or best', 'best', 'list or best', ",
-         "or 'list'.", call. = FALSE)
+    stop0("select_strategy  must be either 'control if available', 'none', ",
+          "control', 'final control', 'control or best', 'best', 'list or best', ",
+          "or 'list'.")
   } else if (isTRUE(select_strategy %in% c("control", "final control", "control or best"))){
     if (is.null(control)){
-      stop("select_strategy is set to 'control', 'final control', or 'control or best', ",
-           "but the trial specification includes no common control.", call. = FALSE)
+      stop0("select_strategy is set to 'control', 'final control', or 'control or best', ",
+            "but the trial specification includes no common control.")
     }
   } else if (isTRUE(select_strategy %in% c("list", "list or best"))){
     arms <- object$trial_spec$trial_arms$arms
     if (is.null(select_preferences) || !isTRUE(all(select_preferences %in% arms)) ||
         any(table(select_preferences) > 1) || length(select_preferences) > length(arms)) {
-      stop("When select_strategy is set to 'list' or 'list or best', ",
-           "select_preferences must be provided as a vector of valid treatment ",
-           "arms with no arms appearing more than once.", call. = FALSE)
+      stop0("When select_strategy is set to 'list' or 'list or best', ",
+            "select_preferences must be provided as a vector of valid treatment ",
+            "arms with no arms appearing more than once.")
     }
   } else if (isTRUE(select_strategy == "control if available")){
     select_strategy  <- if (is.null(control)) "none" else "control"
   } else if (!(select_strategy %in% c("best", "none")) ) {
-    stop("select_strateg must be either 'control if available', 'none', ",
-         "control', 'final control', 'control or best', 'best', 'list or best', ",
-         "or 'list'.", call. = FALSE)
+    stop0("select_strategy must be either 'control if available', 'none', ",
+          "control', 'final control', 'control or best', 'best', 'list or best', ",
+          "or 'list'.")
   }
   if (!isTRUE(select_last_arm %in% c(FALSE, TRUE) && length(select_last_arm) == 1)) {
-    stop("select_last_arm must be either TRUE or FALSE.", call. = FALSE)
+    stop0("select_last_arm must be either TRUE or FALSE.")
   } else if (is.null(control) & select_last_arm) {
-    stop("select_last_arm must be FALSE for trial specifications ",
-         "without a common control arm.", call. = FALSE)
+    stop0("select_last_arm must be FALSE for trial specifications ",
+          "without a common control arm.")
   }
 
   # Validate/set treatment effect comparator
@@ -168,8 +189,8 @@ extract_results <- function(object,
     }
   } else {
     if (length(te_comp) > 1 | !(te_comp %in% object$trial_spec$trial_arms$arms)) {
-      stop("te_comp must be either NULL (in which case the control arm is ",
-           "used if specified) or a single valid arm included in the trial.", call. = FALSE)
+      stop0("te_comp must be either NULL (in which case the control arm is ",
+            "used if specified) or a single valid arm included in the trial.")
     }
   }
   te_comp_index <- if (is.null(te_comp)) NULL else which(te_comp == object$trial_spec$trial_arms$arms)
@@ -177,16 +198,19 @@ extract_results <- function(object,
 
   # Start data extraction
   df <- data.frame(sim = 1:n_rep,
-                   final_n = vapply(1:n_rep, function(x) object$trial_results[[x]]$final_n, FUN.VALUE = numeric(1)),
-                   sum_ys = vapply(1:n_rep, function(x) sum(object$trial_results[[x]]$trial_res$sum_ys), FUN.VALUE = numeric(1)),
-                   ratio_ys = vapply(1:n_rep, function(x) sum(object$trial_results[[x]]$trial_res$sum_ys)/object$trial_results[[x]]$final_n, FUN.VALUE = numeric(1)),
-                   final_status = vapply(1:n_rep, function(x) object$trial_results[[x]]$final_status, FUN.VALUE = character(1)),
+                   final_n = vapply_num(1:n_rep, function(x) object$trial_results[[x]]$final_n),
+                   sum_ys = vapply_num(1:n_rep, function(x) sum(object$trial_results[[x]]$trial_res$sum_ys)),
+                   ratio_ys = vapply_num(1:n_rep, function(x) sum(object$trial_results[[x]]$trial_res$sum_ys)/object$trial_results[[x]]$final_n),
+                   final_status = vapply_str(1:n_rep, function(x) object$trial_results[[x]]$final_status),
                    superior_arm = NA,
                    selected_arm = NA,
                    sq_err = NA,
                    sq_err_te = NA,
                    stringsAsFactors = FALSE)
 
+  # Define which estimates to use
+  which_ests <- paste0(ifelse(raw_ests, "raw", "post"), "_ests", ifelse(final_ests, "_all", ""))
+
   # Loop: selection and error estimation
   for (i in 1:n_rep) {
     tmp_res <- object$trial_results[[i]]$trial_res
@@ -215,7 +239,7 @@ extract_results <- function(object,
       if (select_last_arm & sum(tmp_sel$final_status %in% c("control", "active")) == 1) {
         cur_select <- tmp_sel$arms[tmp_sel$final_status == "control"]
 
-      # Otherwise select according to selection strategy
+        # Otherwise select according to selection strategy
       } else if (isTRUE(select_strategy == "none")) {
         cur_select <- NA
       } else if (isTRUE(select_strategy == "control")) {
@@ -243,12 +267,12 @@ extract_results <- function(object,
     # Calculate errors
     if (!is.na(cur_select)){ # An arm has been selected
       selected_index <- which(tmp_res$arms == cur_select)
-      selected_est_y <- ifelse(raw_ests, tmp_res$raw_ests[selected_index], tmp_res$post_ests[selected_index])
+      selected_est_y <- tmp_res[[which_ests]][selected_index]
       selected_true_y <- tmp_res$true_ys[selected_index]
       df$sq_err[i] <- (selected_est_y - selected_true_y)^2
       if (!is.null(te_comp)){
         if (cur_select != te_comp){
-          te_comp_est_y <- ifelse(raw_ests, tmp_res$raw_ests[te_comp_index], tmp_res$post_ests[te_comp_index])
+          te_comp_est_y <- tmp_res[[which_ests]][te_comp_index]
           df$sq_err_te[i] <- ( (selected_est_y - te_comp_est_y) - (selected_true_y - te_comp_true_y) )^2
         }
       }
