@@ -9,25 +9,37 @@
 #' superiority, equivalence and/or futility as desired; dropping arms, and
 #' re-adjusting allocation probabilities according to the criteria specified in
 #' the trial specification. If there is no common `control` arm, the trial
-#' simulation will be stopped at the maximum sample size, when 1 arm is superior
-#' to the others, or when all arms are considered equivalent (if equivalence
-#' testing is specified).\cr
+#' simulation will be stopped at the final specified adaptive analysis, when 1
+#' arm is superior to the others, or when all arms are considered equivalent (if
+#' equivalence testing is specified).\cr
 #' If a common `control` arm is specified, all other arms will be compared to
-#' that, and if 1 comparison crosses the superiority threshold, that arm will
-#' become the new control and the old control will be considered inferior. If
-#' multiple non-control arms cross the superiority threshold in the same
-#' analysis, the one with the highest probability of being the overall best will
-#' become the new control. Equivalence/futility will also be checked in trial
-#' designs with common controls if specified, and equivalent or futile arms will
-#' be dropped. The trial simulation will be stopped when only 1 arm is left,
-#' when the final arms are all equivalent, or when the maximum sample size has
-#' been reached.
+#' that, and if 1 comparison crosses the applicable superiority threshold at an
+#' adaptive analysis, that arm will become the new control and the old control
+#' will be considered inferior. If multiple non-control arms cross the
+#' applicable superiority threshold in the same adaptive analysis, the one with
+#' the highest probability of being the overall best will become the new
+#' control. Equivalence/futility will also be checked if specified, and
+#' equivalent or futile arms will be dropped in designs with a common `control`
+#' arm and the entire trial will be stopped if all remaining arms are equivalent
+#' in designs without a common `control` arm. The trial simulation will be
+#' stopped when only 1 arm is left, when the final arms are all equivalent, or
+#' after the final specified adaptive analysis.\cr
+#' After stopping (regardless of reason), a final analysis including outcome
+#' data from all patients randomised to all arms will be conducted (with the
+#' final `control` arm, if any, used as the `control` in this analysis).
+#' Results from this analysis will be saved, but not used with regards to the
+#' adaptive stopping rules. This is particularly relevant if less patients have
+#' available outcome data at the adaptive analyses than the total number of
+#' patients randomised (as specified in [setup_trial()], [setup_trial_binom()],
+#' or [setup_trial_norm()]), as the final analysis will then include all
+#' patients randomised, which may be more than in the last adaptive analysis
+#' conducted.
 #'
 #' @param trial_spec `trial_spec` object, generated and validated by the
 #'   [setup_trial()], [setup_trial_binom()] or [setup_trial_norm()] function.
-#' @param seed single integer or `NULL` (default), if a value is provided, this
-#'   value will be used as the random seed when running (the global random seed
-#'   will be restored after the function has run, so it is not affected).
+#' @param seed single integer or `NULL` (default). If a value is provided, this
+#'   value will be used as the random seed when running and the global random
+#'   seed will be restored after the function has run, so it is not affected.
 #' @param sparse single logical; if `FALSE` (default) everything listed below is
 #'   included in the returned object. If `TRUE`, only a limited amount of data
 #'   is included in the returned object. This can be practical when running many
@@ -39,17 +51,26 @@
 #'
 #' @return A `trial_result` object containing everything listed below if
 #'   `sparse` (as described above) is `FALSE`. Otherwise only `final_status`,
-#'   `final_n`, `trial_res`, `seed` and `sparse` are included.
+#'   `final_n`, `followed_n`, `trial_res`, `seed`, and `sparse` are included.
 #'   \itemize{
 #'     \item `final_status`: either `"superiority"`, `"equivalence"`,
-#'       `"futility"`, or `"max"`.
+#'       `"futility"`, or `"max"` (stopped at the last possible adaptive
+#'       analysis), as calculated during the adaptive analyses.
 #'     \item `final_n`: the total number of patients randomised.
-#'     \item `max_n`: the pre-specified maximum sample size.
-#'     \item `looks`: numeric vector, the total number of patients at each
-#'       conducted adaptive analysis.
+#'     \item `followed_n`: the total number of patients with available outcome
+#'       data at the last adaptive analysis conducted.
+#'     \item `max_n`: the pre-specified maximum number of patients with outcome
+#'       data available at the last possible adaptive analysis.
+#'     \item `max_randomised`: the pre-specified maximum number of patients
+#'       randomised at the last possible adaptive analysis.
+#'     \item `looks`: numeric vector, the total number of patients with outcome
+#'       data available at each conducted adaptive analysis.
 #'     \item `planned_looks`: numeric vector, the cumulated number of patients
-#'       planned to be randomised at each adaptive analysis, even those not
-#'       conducted if the simulation is stopped before the maximum sample size.
+#'       planned to have outcome data available at each adaptive analysis, even
+#'       those not conducted if the simulation is stopped before the final
+#'       possible analysis.
+#'     \item `randomised_at_looks`: numeric vector, the total number of patients
+#'       randomised at each conducted adaptive analysis.
 #'     \item `start_control`: character, initial common control arm (if
 #'       specified).
 #'     \item `final_control`: character, final common control arm (if relevant).
@@ -63,48 +84,58 @@
 #'     \item `trial_res`: a `data.frame` containing most of the information
 #'       specified for each arm in [setup_trial()] including `true_ys` (true
 #'       outcomes as specified in [setup_trial()]) and for each arm the sum of
-#'       the outcomes (`sum_ys`; i.e., the total number of events for binary
-#'       outcomes or the totals of continuous outcomes) and patients randomised
-#'       (`ns`), summary statistics for the raw outcome data (`raw_ests`,
-#'       calculated as specified in [setup_trial()], defaults to mean values,
-#'       i.e., event rates for binary outcomes or means for continuous outcomes)
-#'       and posterior estimates (`post_ests`, `post_errs`, `lo_cri`, and
-#'       `hi_cri`, as specified in [setup_trial()]), `final_status` of each arm
+#'       the outcomes (`sum_ys`/`sum_ys_all`; i.e., the total number of events
+#'       for binary outcomes or the totals of continuous outcomes) and sum of
+#'       patients (`ns`/`ns_all`), summary statistics for the raw outcome data
+#'       (`raw_ests`/`raw_ests_all`, calculated as specified in [setup_trial()],
+#'       defaults to mean values, i.e., event rates for binary outcomes or means
+#'       for continuous outcomes) and posterior estimates
+#'       (`post_ests`/`post_ests_all`, `post_errs`/`post_errs_all`,
+#'       `lo_cri`/`lo_cri_all`, and `hi_cri`/`hi_cri_all`, calculated as
+#'       specified in [setup_trial()]), `final_status` of each arm
 #'       (`"inferior"`, `"superior"`, `"equivalence"`, `"futile"`, `"active"`,
 #'       or `"control"` (currently active control arm, including if the current
-#'       control when stopped for equivalence)),
-#'       `status_look` (specifying the cumulated number of patients randomised
-#'       when an adaptive analysis changed the `final_status` to `"superior"`,
+#'       control when stopped for equivalence)), `status_look` (specifying the
+#'       cumulated number of patients with outcome data available when an
+#'       adaptive analysis changed the `final_status` to `"superior"`,
 #'       `"inferior"`, `"equivalence"`, or `"futile"`), `status_probs`, the
-#'       probability that each treatment was the best/better than the common
-#'       control arm (if any)/equivalent to the common control arm (if any and
-#'       stopped for equivalence; `NA` if the control arm was stopped due to the
-#'       last remaining other arm(s) being stopped for equivalence)/futile if
-#'       stopped for futility at the last analysis it was included in,
-#'       `final_alloc`, the final allocation probability for each arm the last
-#'       time patients were randomised to it, including for arms stopped at the
-#'       maximum sample size, and `probs_best_last`, the probabilities of each
-#'       remaining arm being the overall best in the last conducted analysis
-#'       (`NA` for previously dropped arms).
+#'       probability (in the last adaptive analysis for each arm) that each
+#'       arm was the best/better than the common control arm (if any)/equivalent
+#'       to the common control arm (if any and stopped for equivalence; `NA` if
+#'       the control arm was stopped due to the last remaining other arm(s)
+#'       being stopped for equivalence)/futile if stopped for futility at the
+#'       last analysis it was included in, `final_alloc`, the final allocation
+#'       probability for each arm the last time patients were randomised to it,
+#'       including for arms stopped at the maximum sample size, and
+#'       `probs_best_last`, the probabilities of each remaining arm being the
+#'       overall best in the last conducted adaptive analysis (`NA` for
+#'       previously dropped arms).\cr
+#'       **Note:** for the variables in the `data.frame` where a version
+#'       including the `_all`-suffix is included, the versions WITHOUT this
+#'       suffix are calculated using patients with available outcome data at the
+#'       time of analysis, while the versions WITH the `_all`-suffixes are
+#'       calculated using outcome data for all patients randomised at the time
+#'       of analysis, even if they have not reached the time of follow-up yet
+#'       (see [setup_trial()]).
 #'     \item `all_looks`: a list of lists containing one list per conducted
 #'       trial look (adaptive analysis). These lists contain the variables
 #'       `arms`, `old_status` (status before the analysis of the current round
 #'       was conducted), `new_status` (as specified above, status after current
-#'       analysis has been conducted), `sum_ys` (as described above), `ns` (as
-#'       described above), `old_alloc` (the allocation probability used during
-#'       this look), `probs_best` (the probabilities of each arm being the best
-#'       in the current adaptive analysis), `new_alloc` (the allocation
-#'       probabilities after updating these in the current adaptive analysis; NA
-#'       for all arms when the trial is stopped and no further analyses will be
-#'       conducted), `probs_better_first` (if a common control is provided,
-#'       specifying the probabilities that each arm was better than the control
-#'       in the first analysis conducted during that look), `probs_better` (as
-#'       `probs_better_first`, but updated if another arm becomes the new
-#'       control), `probs_equivalence_first` and `probs_equivalence` (as for
-#'       `probs_better`/`probs_better_first`, but for equivalence if equivalence
-#'       is assessed). The last variables are `NA` if the arm was not active in
-#'       the applicable adaptive analysis or if they would not be included
-#'       during the next adaptive analysis.
+#'       analysis has been conducted), `sum_ys`/`sum_ys_all` (as described
+#'       above), `ns`/`ns_all` (as described above), `old_alloc` (the allocation
+#'       probability used during this look), `probs_best` (the probabilities of
+#'       each arm being the best in the current adaptive analysis), `new_alloc`
+#'       (the allocation probabilities after updating these in the current
+#'       adaptive analysis; NA for all arms when the trial is stopped and no
+#'       further adaptive analyses will be conducted), `probs_better_first` (if
+#'       a common control is provided, specifying the probabilities that each
+#'       arm was better than the control in the first analysis conducted during
+#'       that look), `probs_better` (as `probs_better_first`, but updated if
+#'       another arm becomes the new control), `probs_equivalence_first` and
+#'       `probs_equivalence` (as for `probs_better`/`probs_better_first`, but
+#'       for equivalence if equivalence is assessed). The last variables are
+#'       `NA` if the arm was not active in the applicable adaptive analysis or
+#'       if they would not be included during the next adaptive analysis.
 #'     \item `allocs`: a character vector containing the allocations of all
 #'       patients in the order of randomization.
 #'     \item `ys`: a numeric vector containing the outcomes of all patients in
@@ -136,13 +167,14 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
 
   # Check class (validation takes place when the trial is setup)
   if (!inherits(trial_spec, "trial_spec")) {
-    stop("trial_spec must be an object created by the setup_trial, ",
-         "setup_trial_binom or setup_trial_norm function.", call. = FALSE)
+    stop0("trial_spec must be an object created by the setup_trial, ",
+          "setup_trial_binom or setup_trial_norm function.")
   }
+
   # Random seed
   if (!is.null(seed)) {
     if (!verify_int(seed)) {
-      stop("seed must be either NULL or a single whole number.", call. = FALSE)
+      stop0("seed must be either NULL or a single whole number.")
     } else { # Valid seed provided
       if (exists(".Random.seed", envir = globalenv())){ # A global random seed exists (not the case when called from parallel::parLapply)
         oldseed <- get(".Random.seed", envir = globalenv())
@@ -153,7 +185,7 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
   }
   # Validate sparse
   if (is.null(sparse) | length(sparse) != 1 | any(is.na(sparse)) | !is.logical(sparse)) {
-    stop("sparse must be a single TRUE or FALSE.", call. = FALSE)
+    stop0("sparse must be a single TRUE or FALSE.")
   }
 
   # Prepare variables/extract from specification
@@ -165,30 +197,42 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
   true_ys <- trial_arms$true_ys
   n_arms <- length(arms)
   aai <- 1:n_arms # aai = active arm indices
-  sum_ys <- rep(0, n_arms)
-  ns <- rep(0, n_arms)
+  sum_ys <- sum_ys_all <- ns <- ns_all <- rep(0, n_arms)
   total_n <- 0
+  n_data_looks <- trial_spec$n_data_looks
   inferiority <- trial_spec$inferiority
+  if (length(inferiority) == 1) {
+    inferiority <- rep(inferiority, n_data_looks)
+  }
   superiority <- trial_spec$superiority
+  if (length(superiority) == 1) {
+    superiority <- rep(superiority, n_data_looks)
+  }
   equivalence_prob <- trial_spec$equivalence_prob
   equivalence_diff <- trial_spec$equivalence_diff
   equivalence_only_first <- trial_spec$equivalence_only_first
   check_equivalence <- !is.null(equivalence_prob)
+  if (check_equivalence & length(equivalence_prob) == 1) {
+    equivalence_prob <- rep(equivalence_prob, n_data_looks)
+  }
   equivalence_stop <- FALSE
   prob_all_equivalent <- NULL
   futility_diff <- trial_spec$futility_diff
   futility_prob <- trial_spec$futility_prob
   futility_only_first <- trial_spec$futility_only_first
   check_futility <- !is.null(futility_prob)
+  if (check_futility & length(futility_prob) == 1) {
+    futility_prob <- rep(futility_prob, n_data_looks)
+  }
   futility_stop <- FALSE
   highest_is_best <- trial_spec$highest_is_best
   cri_width <- trial_spec$cri_width
   n_draws <- trial_spec$n_draws
   robust <- trial_spec$robust
   data_looks <- trial_spec$data_looks
-  n_data_looks <- trial_spec$n_data_looks
-  allocs <- rep(NA_character_, data_looks[n_data_looks]) # All allocations
-  ys <- rep(NA_real_, data_looks[n_data_looks]) # All outcomes
+  randomised_at_looks <- trial_spec$randomised_at_looks
+  allocs <- rep(NA_character_, randomised_at_looks[n_data_looks]) # All allocations
+  ys <- rep(NA_real_, randomised_at_looks[n_data_looks]) # All outcomes
   fun_y_gen <- trial_spec$fun_y_gen
   fun_draws <- trial_spec$fun_draws
   # Prepare objects with final/current statuses
@@ -196,14 +240,13 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
   trial_arms$status_look <- rep(NA, n_arms)
   trial_arms$status_probs <- rep(NA, n_arms)
   trial_arms$final_alloc <- rep(NA, n_arms)
-  trial_arms$sum_ys <- rep(NA, n_arms)
   trial_arms$probs_best_last <- rep(NA, n_arms)
   post <- matrix(rep(NA, 4*n_arms), ncol = 4) # Contains current/final posterior for each arm
   cur_status <- list(arms = arms,
                      old_status = rep("active", n_arms),
                      new_status = rep("active", n_arms),
-                     sum_ys = sum_ys,
-                     ns = ns,
+                     sum_ys = sum_ys, sum_ys_all = sum_ys_all,
+                     ns = ns, ns_all = ns_all,
                      old_alloc = rep(NA, n_arms),
                      probs_best = rep(NA, n_arms),
                      new_alloc = trial_arms$start_probs)
@@ -226,18 +269,23 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
     cur_status$old_alloc <- cur_status$new_alloc
     cur_status$new_alloc <- rep(NA, n_arms) # Delete old values
     aai <- which(cur_status$new_status %in% c("active", "control"))
-    n_new <- data_looks[look] - total_n
-    new_patients <- sample(arms[aai], size = n_new, prob = cur_status$old_alloc[aai], replace = TRUE)
-    allocs[(total_n+1):(total_n+n_new)] <- new_patients
-    ys[(total_n+1):(total_n+n_new)] <- fun_y_gen(new_patients)
-    total_n <- data_looks[look]
-    cur_status$ns <- ns <- vapply(arms, function(a) sum(allocs == a, na.rm = TRUE), integer(1))
+    n_new <- randomised_at_looks[look] - total_n
+    if (n_new > 0) { # If no more patients are randomised at this analysis (but more have reached follow-up)
+      new_patients <- sample(arms[aai], size = n_new, prob = cur_status$old_alloc[aai], replace = TRUE)
+      allocs[(total_n+1):(total_n+n_new)] <- new_patients
+      ys[(total_n+1):(total_n+n_new)] <- fun_y_gen(new_patients)
+    }
+    followed_n <- data_looks[look] # Number of patients with outcome data
+    total_n <- randomised_at_looks[look] # Number of patients randomised
+    cur_status$ns[aai] <- ns[aai] <- vapply_int(arms[aai], function(a) sum(allocs[1:followed_n] == a))
+    cur_status$ns_all <- ns_all <- vapply_int(arms, function(a) sum(allocs[1:total_n] == a))
     # which() required to avoid summing over NA's (which yields an NA sum)
-    cur_status$sum_ys <- sum_ys <- vapply(arms, function(a) sum(ys[which(allocs == a)]), numeric(1))
+    cur_status$sum_ys[aai] <- sum_ys[aai] <- vapply_num(arms[aai], function(a) sum(ys[which(allocs[1:followed_n] == a)]))
+    cur_status$sum_ys_all <- sum_ys_all <- vapply_num(arms, function(a) sum(ys[which(allocs[1:total_n] == a)]))
 
     # Get draws and probabilities that each treatment is superior (and better/equivalent if specified)
-    draws <- fun_draws(arms = arms[aai], allocs = allocs[1:total_n],
-                       ys = ys[1:total_n], control = control, n_draws = n_draws)
+    draws <- fun_draws(arms = arms[aai], allocs = allocs[1:followed_n],
+                       ys = ys[1:followed_n], control = control, n_draws = n_draws)
     probs_best <- prob_best(draws, highest_is_best)
     cur_status$probs_best <- rep(NA, n_arms) # Delete old values
     cur_status$probs_best[aai] <- probs_best # Save the first set of best values this round, only for active arms
@@ -276,36 +324,36 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
       # Keep removing inferior arms until they are all dropped
       # - for every inferior arm dropped, draws/probabilities are updated
       check_equivalence <- !is.null(equivalence_prob)
-      while(any(probs_best < inferiority)) {
-        inferior_probs <- probs_best[probs_best < inferiority]
-        inferior_arms <- names(probs_best)[probs_best < inferiority]
+      while(any(probs_best < inferiority[look])) {
+        inferior_probs <- probs_best[probs_best < inferiority[look]]
+        inferior_arms <- names(probs_best)[probs_best < inferiority[look]]
 
         for (i in seq_along(inferior_arms)) {
           cur_index <- which(cur_status$arms == inferior_arms[i])
           cur_status$new_status[cur_index] <- "inferior"
           aai <- aai[!(aai == cur_index)]
           trial_arms$final_status[cur_index] <- "inferior"
-          trial_arms$status_look[cur_index] <- total_n
+          trial_arms$status_look[cur_index] <- followed_n
           trial_arms$status_probs[cur_index] <- inferior_probs[i]
           trial_arms$final_alloc[cur_index] <- cur_status$old_alloc[cur_index]
           post[cur_index, ] <- summarise_dist(draws[, inferior_arms[i]], robust, cri_width)
         }
 
         # Update draws again
-        draws <- fun_draws(arms = arms[aai], allocs = allocs[1:total_n],
-                           ys = ys[1:total_n], control = control, n_draws = n_draws)
+        draws <- fun_draws(arms = arms[aai], allocs = allocs[1:followed_n],
+                           ys = ys[1:followed_n], control = control, n_draws = n_draws)
         probs_best <- prob_best(draws, highest_is_best)
       } # End inferiority checks no common control
 
       # Check if an arm is superior
       superior_prob <- max(probs_best)
-      if (superior_prob > superiority) {
+      if (superior_prob > superiority[look]) {
         superior_arm <- names(probs_best)[which.max(probs_best)]
         cur_index <- which(cur_status$arms == superior_arm)
         cur_status$new_status[cur_index] <- "superior"
         aai <- cur_index
         trial_arms$final_status[cur_index] <- "superior"
-        trial_arms$status_look[cur_index] <- total_n
+        trial_arms$status_look[cur_index] <- followed_n
         trial_arms$status_probs[cur_index] <- superior_prob
         trial_arms$final_alloc[cur_index] <- cur_status$old_alloc[cur_index]
         post[cur_index, ] <- summarise_dist(draws[, superior_arm], robust, cri_width)
@@ -316,10 +364,10 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
       # Equivalence check no common control
       if (check_equivalence) {
         prob_all_equivalent <- prob_all_equi(draws, equivalence_diff)
-        if (prob_all_equivalent > equivalence_prob){
+        if (prob_all_equivalent > equivalence_prob[look]){
           cur_status$new_status[aai] <- "equivalence"
           trial_arms$final_status[aai] <- "equivalence"
-          trial_arms$status_look[aai] <- total_n
+          trial_arms$status_look[aai] <- followed_n
           trial_arms$status_probs[aai] <- probs_best
           trial_arms$final_alloc[aai] <- cur_status$old_alloc[aai]
           for (ie in aai){
@@ -342,7 +390,7 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
       }
 
 
-    # Common control
+      # Common control
     } else { # Common control:
       run_check <- TRUE # Used to signal that it is necessary to run a new round of checks - checks must be run multiple times if new control is found
       update_draws <- FALSE # Only update if arms dropped
@@ -354,9 +402,9 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
 
         # Inferiority checks common control
         # Check if at least one arm is inferior to the control - if that is the case, then drop all inferior arms
-        # No need to re-run this part after each inferior arm is dropped, as all comparisons are relative to the contorl only
-        if (any(probs_better < inferiority, na.rm = TRUE)) {
-          which_inferior <- which(probs_better < inferiority)
+        # No need to re-run this part after each inferior arm is dropped, as all comparisons are relative to the control only
+        if (any(probs_better < inferiority[look], na.rm = TRUE)) {
+          which_inferior <- which(probs_better < inferiority[look])
           inferior_arms <- rownames(probs_res_better)[which_inferior]
           inferior_probs <- probs_better[which_inferior]
           update_draws <- TRUE
@@ -366,7 +414,7 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
             cur_status$new_status[cur_index] <- "inferior"
             aai <- aai[aai != cur_index]
             trial_arms$final_status[cur_index] <- "inferior"
-            trial_arms$status_look[cur_index] <- total_n
+            trial_arms$status_look[cur_index] <- followed_n
             trial_arms$status_probs[cur_index] <- inferior_probs[i]
             trial_arms$final_alloc[cur_index] <- cur_status$old_alloc[cur_index]
             post[cur_index, ] <- summarise_dist(draws[, inferior_arms[i]], robust, cri_width)
@@ -377,7 +425,7 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
         # Superiority check common control
         # Not necessary to update draws again before superiority has been claimed
         # Relative superiority check common control
-        if (any(probs_better > superiority, na.rm = TRUE)) { # Set new control - only 1 is declared superior at a time (if multiple are better, the best is chosen)
+        if (any(probs_better > superiority[look], na.rm = TRUE)) { # Set new control - only 1 is declared superior at a time (if multiple are better, the best is chosen)
           update_draws <- TRUE
           new_control <- rownames(probs_res_better)[which.max(probs_better)]
           cur_index <- which(cur_status$arms == new_control)
@@ -385,7 +433,7 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
           cur_status$new_status[control_index] <- "inferior"
           aai <- aai[!(aai == control_index)]
           trial_arms$final_status[control_index] <- "inferior"
-          trial_arms$status_look[control_index] <- total_n
+          trial_arms$status_look[control_index] <- followed_n
           trial_arms$status_probs[control_index] <- 1 - max(probs_better, na.rm = TRUE)
           trial_arms$final_alloc[control_index] <- cur_status$old_alloc[control_index]
           post[control_index, ]  <- summarise_dist(draws[, control], robust, cri_width)
@@ -403,8 +451,8 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
           # obtained if one arm has just been deemed superior and made the new control
         } else {
           if (check_equivalence) {
-            if (any(probs_equivalence > equivalence_prob, na.rm = TRUE)) {
-              which_equivalent <- which(probs_equivalence > equivalence_prob)
+            if (any(probs_equivalence > equivalence_prob[look], na.rm = TRUE)) {
+              which_equivalent <- which(probs_equivalence > equivalence_prob[look])
               equivalent_arms <- rownames(probs_res_better)[which_equivalent]
               equivalence_probs <- probs_equivalence[which_equivalent]
               update_draws <- TRUE
@@ -414,7 +462,7 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
                 cur_status$new_status[cur_index] <- "equivalence"
                 aai <- aai[aai != cur_index]
                 trial_arms$final_status[cur_index] <- "equivalence"
-                trial_arms$status_look[cur_index] <- total_n
+                trial_arms$status_look[cur_index] <- followed_n
                 trial_arms$status_probs[cur_index] <- equivalence_probs[i]
                 trial_arms$final_alloc[cur_index] <- cur_status$old_alloc[cur_index]
                 post[cur_index, ]  <- summarise_dist(draws[, equivalent_arms[i]], robust, cri_width)
@@ -429,8 +477,8 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
 
           # Futility check common control
           if (check_futility) {
-            if (any(probs_futility > futility_prob, na.rm = TRUE)) {
-              which_futile <- which(probs_futility > futility_prob)
+            if (any(probs_futility > futility_prob[look], na.rm = TRUE)) {
+              which_futile <- which(probs_futility > futility_prob[look])
               futile_arms <- rownames(probs_res_better)[which_futile]
               # Don't consider an arm futile if it's already judged to be equivalent
               non_equi_index <- !futile_arms %in% cur_status$arms[which(cur_status$new_status == "equivalence")]
@@ -445,14 +493,14 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
                   cur_status$new_status[cur_index] <- "futile"
                   aai <- aai[aai != cur_index]
                   trial_arms$final_status[cur_index] <- "futile"
-                  trial_arms$status_look[cur_index] <- total_n
+                  trial_arms$status_look[cur_index] <- followed_n
                   trial_arms$status_probs[cur_index] <- futility_probs[i]
                   trial_arms$final_alloc[cur_index] <- cur_status$old_alloc[cur_index]
                   post[cur_index, ] <- summarise_dist(draws[, futile_arms[i]], robust, cri_width)
                 }
 
                 if (length(aai) == 1) {
-                  futility_stop <- TRUE # Only one arm lefter - others stopped for futility
+                  futility_stop <- TRUE # Only one arm left - others stopped for futility
                 }
               }
             }
@@ -465,7 +513,7 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
           cur_index <- aai
           cur_status$new_status[cur_index] <- if (equivalence_stop | futility_stop) "active" else "superior"
           trial_arms$final_status[cur_index] <- if (equivalence_stop | futility_stop) "active" else "superior"
-          trial_arms$status_look[cur_index] <- total_n
+          trial_arms$status_look[cur_index] <- followed_n
 
           if (any(!is.na(probs_better)) & !equivalence_stop & !futility_stop) { # Only if some are not NA, to avoid problems when checking for the last control (and if not stopped for equivalence/futility)
             trial_arms$status_probs[cur_index] <- max(na.omit(probs_better), 1 - na.omit(probs_better)) # Get highest of the current relative probs for last control (2+ comparisons, or inverse)
@@ -478,8 +526,8 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
 
         # Get updated draws and probabilities that each treatment is superior again if necessary (otherwise reuse)
         if (update_draws) {
-          draws <- fun_draws(arms = arms[aai], allocs = allocs[1:total_n],
-                             ys = ys[1:total_n], control = control, n_draws = n_draws)
+          draws <- fun_draws(arms = arms[aai], allocs = allocs[1:followed_n],
+                             ys = ys[1:followed_n], control = control, n_draws = n_draws)
           probs_best <- prob_best(draws, highest_is_best)
 
           if (run_check) { # New control, updated
@@ -578,7 +626,9 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
   }
 
   trial_arms$sum_ys <- sum_ys
+  trial_arms$sum_ys_all <- sum_ys_all
   trial_arms$ns <- ns
+  trial_arms$ns_all <- ns_all
 
   # Add final_alloc, post_ests and post_errs for remaining arms
   for (i in aai) {
@@ -594,18 +644,34 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
     }
   }
 
+  # Conduct final analysis including all patients from all arms
+  draws_final <- fun_draws(arms = arms, allocs = allocs[1:total_n],
+                           ys = ys[1:total_n], control = control, n_draws = n_draws)
+  post_final <- matrix(rep(NA, 4*n_arms), ncol = 4)
+  for (i in 1:n_arms) {
+    post_final[i, ] <- summarise_dist(draws_final[, arms[i]], robust, cri_width)
+  }
+
   # Save posterior and raw estimates and final probabilities of being best
   trial_arms$post_ests <- post[, 1]
   trial_arms$post_errs <- post[, 2]
   trial_arms$lo_cri <- post[, 3]
   trial_arms$hi_cri <- post[, 4]
-  trial_arms$raw_ests <- vapply(arms, function(a) trial_spec$fun_raw_est(ys[1:total_n][which(allocs[1:total_n] == a)]), numeric(1))
-  trial_arms$probs_best_last <- vapply(arms, function(a) ifelse(a %in% names(probs_best), probs_best[which(names(probs_best) == a)], NA), numeric(1))
+  status_ns <- ifelse(is.na(trial_arms$status_look), followed_n, trial_arms$status_look)
+  trial_arms$raw_ests <- vapply_num(1:n_arms, function(i) trial_spec$fun_raw_est(ys[1:status_ns[i]][which(allocs[1:status_ns[i]] == arms[i])]))
+  trial_arms$post_ests_all <- post_final[, 1]
+  trial_arms$post_errs_all <- post_final[, 2]
+  trial_arms$lo_cri_all <- post_final[, 3]
+  trial_arms$hi_cri_all <- post_final[, 4]
+  trial_arms$raw_ests_all <- vapply_num(arms, function(a) trial_spec$fun_raw_est(ys[1:total_n][which(allocs[1:total_n] == a)]))
+  trial_arms$probs_best_last <- vapply_num(arms, function(a) ifelse(a %in% names(probs_best), probs_best[which(names(probs_best) == a)], NA))
 
   # Rearrange values in trial_arms and convert to data.frame
   trial_arms_cols <- c("arms", "true_ys", "start_probs", "fixed_probs", "min_probs",
-                       "max_probs", "sum_ys", "ns", "raw_ests", "post_ests",
-                       "post_errs", "lo_cri", "hi_cri", "final_status",
+                       "max_probs", "sum_ys", "ns", "sum_ys_all", "ns_all",
+                       "raw_ests", "post_ests", "post_errs", "lo_cri", "hi_cri",
+                       "raw_ests_all", "post_ests_all", "post_errs_all",
+                       "lo_cri_all", "hi_cri_all", "final_status",
                        "status_look", "status_probs", "final_alloc", "probs_best_last")
   trial_arms <- as.data.frame(trial_arms, stringsAsFactors = FALSE)[, trial_arms_cols]
 
@@ -613,6 +679,7 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
   if (sparse){
     structure(list(final_status = final_status,
                    final_n = total_n,
+                   followed_n = followed_n,
                    trial_res = trial_arms,
                    seed = seed,
                    sparse = TRUE),
@@ -620,18 +687,21 @@ run_trial <- function(trial_spec, seed = NULL, sparse = FALSE) {
   } else {
     structure(list(final_status = final_status,
                    final_n = total_n,
+                   followed_n = followed_n,
                    max_n = data_looks[n_data_looks],
+                   max_randomised = max(randomised_at_looks),
                    looks = data_looks[1:look],
                    planned_looks = data_looks,
+                   randomised_at_looks = randomised_at_looks[1:look],
                    start_control = trial_spec$control,
                    final_control = control,
                    control_prob_fixed = control_prob_fixed,
-                   inferiority = inferiority,
-                   superiority = superiority,
-                   equivalence_prob = equivalence_prob,
+                   inferiority = trial_spec$inferiority,
+                   superiority = trial_spec$superiority,
+                   equivalence_prob = trial_spec$equivalence_prob,
                    equivalence_diff = equivalence_diff,
                    equivalence_only_first = equivalence_only_first,
-                   futility_prob = futility_prob,
+                   futility_prob = trial_spec$futility_prob,
                    futility_diff = futility_diff,
                    futility_only_first = futility_only_first,
                    highest_is_best = highest_is_best,
